
"""
$Id: testCVSObjects.py,v 1.3 2003/05/02 13:58:12 philipp Exp $
"""

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Testing import ZopeTestCase
import Products
from Products.RevisionManager.CVSObjects import CVSFile, CVSDirectory
from Products.RevisionManager.interfaces.RevisionControlled import \
     IRCFile, IRCDirectory

ZopeTestCase.installProduct('RevisionManager')

TESTFILES_DIR = os.path.join(os.path.dirname(Products.RevisionManager.__file__),
                             'tests', 'testfiles')

class CVSFileTest(ZopeTestCase.ZopeTestCase):

    def afterSetUp(self):
        self.directory = CVSDirectory(TESTFILES_DIR, '')

    def afterClear(self):
        pass

    def test_iverify(self):
        """Verify interface implementation of CVSFile"""
        from Interface.Verify import verifyObject
        cvsfile = self.directory.getContents()[0]
        self.failUnless(verifyObject(IRCFile, cvsfile))
        self.failIf(cvsfile.isDirectory)

class CVSDirectoryTest(ZopeTestCase.ZopeTestCase):

    def afterSetUp(self):
        self.directory = CVSDirectory(TESTFILES_DIR, '')

    def afterClear(self):
        pass

    def test_iverify(self):
        """Verify interface implementation of CVSDirectory"""
        from Interface.Verify import verifyObject
        self.failUnless(verifyObject(IRCDirectory, self.directory))
        self.failUnless(self.directory.isDirectory)

    def test_has_file(self):
        """Test hasFile()"""
        directory = self.directory
        expected = os.listdir(TESTFILES_DIR)
        expected.remove("CVS")
        for filename in expected:
            self.failUnless(directory.hasFile(filename))
        self.failIf(directory.hasFile('definitelynotindirectory'))

    def test_get_file_object(self):
        """Test getFileObject()"""
        directory = self.directory
        helloworld = directory.getFileObject('helloworld.txt')
        self.failUnless(helloworld.__class__ is CVSFile)
        self.assertRaises(ValueError, directory.getFileObject, 'definitelynotindirectory')

    def test_get_contents(self):
        """Test getContents()"""
        directory = self.directory
        contents = directory.getContents()
        filenames = [obj.filename for obj in contents]
        self.assertEqual(filenames, directory.getDirectoryListing())

    def test_directory_listing(self):
        """Test directory listing"""
        expected = os.listdir(TESTFILES_DIR)
        expected.remove("CVS")
        expected.sort()
        self.assertEqual(self.directory.getDirectoryListing(1), expected)

    def test_traverse(self):
        """Test file object traversal"""
        directory = self.directory
        self.failUnless(directory.traverse('') is directory)
        self.failUnless(directory.traverse('helloworld.txt') is directory.getFileObject('helloworld.txt'))
        marker = []
        self.failUnless(directory.traverse('definitelynotindirectory', marker) is marker)
        #XXX missing traversal through subdirectories

if __name__ == '__main__':
    framework(descriptions=1, verbosity=2)
else:
    import unittest
    def test_suite():
        suite = unittest.TestSuite()
        suite.addTest(unittest.makeSuite(CVSFileTest))
        suite.addTest(unittest.makeSuite(CVSDirectoryTest))
        return suite

